@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 import os
 
 ACC_ENV_KEY = "USDKACC"
@@ -10,12 +8,12 @@ def get_skip_reason():
     return ACC_SKIP_REASON
 
 
-def is_acc():
+def is_acc() -> bool:
     """ check test env is acceptance testing or not """
     return os.getenv(ACC_ENV_KEY)
 
 
-def is_ut():
+def is_ut() -> bool:
     """ check test env is unit testing or not """
     return not is_acc()
 
